@@ -9,17 +9,17 @@
 
 #include <CalendarSupport/Utils>
 
-#include <KCalendarCore/Attachment>
 #include <KCalendarCore/Alarm>
+#include <KCalendarCore/Attachment>
 #include <KCalendarCore/Event>
-#include <KCalendarCore/Todo>
 #include <KCalendarCore/Journal>
+#include <KCalendarCore/Todo>
 
 #include <KLocalizedString>
 
+#include <QCoreApplication>
 #include <QList>
 #include <QTextStream>
-#include <QCoreApplication>
 
 #define TEXT_WIDTH 75
 
@@ -40,8 +40,7 @@ static void bailOut()
 
 static bool collectionIsReadOnly(const Akonadi::Collection &collection)
 {
-    return !(collection.rights() & Akonadi::Collection::CanChangeItem)
-           || !(collection.rights() & Akonadi::Collection::CanDeleteItem);
+    return !(collection.rights() & Akonadi::Collection::CanChangeItem) || !(collection.rights() & Akonadi::Collection::CanDeleteItem);
 }
 
 static bool incidenceIsOld(const KCalendarCore::Incidence::Ptr &incidence)
@@ -58,7 +57,8 @@ static bool incidenceIsOld(const KCalendarCore::Incidence::Ptr &incidence)
     return datetime.isValid() && datetime.daysTo(QDateTime::currentDateTime()) > 365;
 }
 
-CalendarJanitor::CalendarJanitor(const Options &options, QObject *parent) : QObject(parent)
+CalendarJanitor::CalendarJanitor(const Options &options, QObject *parent)
+    : QObject(parent)
     , m_collectionLoader(new CollectionLoader(this))
     , m_options(options)
     , m_currentSanityCheck(Options::CheckNone)
@@ -88,7 +88,8 @@ void CalendarJanitor::onCollectionsFetched(bool success)
         return;
     }
 
-    foreach (const Akonadi::Collection &collection, m_collectionLoader->collections()) {
+    const auto collections = m_collectionLoader->collections();
+    for (const Akonadi::Collection &collection : collections) {
         if (m_options.testCollection(collection.id())) {
             m_collectionsToProcess << collection;
         }
@@ -120,7 +121,7 @@ void CalendarJanitor::onItemsFetched(bool success, const QString &errorMessage)
 
 void CalendarJanitor::onModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage)
 {
-    Q_UNUSED(changeId);
+    Q_UNUSED(changeId)
     if (resultCode != Akonadi::IncidenceChanger::ResultCodeSuccess) {
         print(i18n("Error while modifying incidence: %1", errorMessage));
         bailOut();
@@ -136,9 +137,12 @@ void CalendarJanitor::onModifyFinished(int changeId, const Akonadi::Item &item,
     }
 }
 
-void CalendarJanitor::onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &items, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage)
+void CalendarJanitor::onDeleteFinished(int changeId,
+                                       const QVector<Akonadi::Item::Id> &items,
+                                       Akonadi::IncidenceChanger::ResultCode resultCode,
+                                       const QString &errorMessage)
 {
-    Q_UNUSED(changeId);
+    Q_UNUSED(changeId)
     if (resultCode != Akonadi::IncidenceChanger::ResultCodeSuccess) {
         print(i18n("Error while deleting incidence: %1", errorMessage));
         bailOut();
@@ -184,7 +188,7 @@ void CalendarJanitor::processNextCollection()
         processNextCollection();
     } else {
         m_incidenceMap.clear();
-        foreach (const Akonadi::Item &item, m_itemsToProcess) {
+        for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
             KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
             Q_ASSERT(incidence);
             m_incidenceMap.insert(incidence->instanceIdentifier(), incidence);
@@ -250,10 +254,9 @@ void CalendarJanitor::sanityCheck1()
 {
     beginTest(i18n("Checking for incidences with empty summary and description..."));
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
-        if (incidence->summary().isEmpty() && incidence->description().isEmpty()
-            && incidence->attachments().isEmpty()) {
+        if (incidence->summary().isEmpty() && incidence->description().isEmpty() && incidence->attachments().isEmpty()) {
             printFound(item);
             deleteIncidence(item);
         }
@@ -266,7 +269,7 @@ void CalendarJanitor::sanityCheck2()
 {
     beginTest(i18n("Checking for incidences with empty UID..."));
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         if (incidence->uid().isEmpty()) {
             printFound(item);
@@ -284,7 +287,7 @@ void CalendarJanitor::sanityCheck2()
 void CalendarJanitor::sanityCheck3()
 {
     beginTest(i18n("Checking for events with invalid DTSTART..."));
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         KCalendarCore::Event::Ptr event = incidence.dynamicCast<KCalendarCore::Event>();
         if (!event) {
@@ -321,7 +324,7 @@ void CalendarJanitor::sanityCheck3()
 void CalendarJanitor::sanityCheck4()
 {
     beginTest(i18n("Checking for recurring to-dos with invalid DTSTART..."));
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         KCalendarCore::Todo::Ptr todo = incidence.dynamicCast<KCalendarCore::Todo>();
         if (!todo) {
@@ -357,7 +360,7 @@ void CalendarJanitor::sanityCheck4()
 void CalendarJanitor::sanityCheck5()
 {
     beginTest(i18n("Checking for journals with invalid DTSTART..."));
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         if (incidence->type() != KCalendarCore::Incidence::TypeJournal) {
             continue;
@@ -379,7 +382,7 @@ void CalendarJanitor::sanityCheck6()
 {
     beginTest(i18n("Checking for orphans...")); // Incidences without a parent
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         const QString parentUid = incidence->relatedTo();
         if (!parentUid.isEmpty() && !m_calendar->incidence(parentUid)) {
@@ -399,15 +402,15 @@ void CalendarJanitor::sanityCheck7()
 {
     beginTest(i18n("Checking for duplicate UIDs..."));
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
-        QList<KCalendarCore::Incidence::Ptr> existingIncidences = m_incidenceMap.values(incidence->instanceIdentifier());
+        const QList<KCalendarCore::Incidence::Ptr> existingIncidences = m_incidenceMap.values(incidence->instanceIdentifier());
 
         if (existingIncidences.count() == 1) {
             continue;
         }
 
-        foreach (const KCalendarCore::Incidence::Ptr &existingIncidence, existingIncidences) {
+        for (const KCalendarCore::Incidence::Ptr &existingIncidence : existingIncidences) {
             if (existingIncidence != incidence && *incidence == *existingIncidence) {
                 printFound(item);
                 deleteIncidence(item);
@@ -416,9 +419,9 @@ void CalendarJanitor::sanityCheck7()
         }
     }
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
-        QList<KCalendarCore::Incidence::Ptr> existingIncidences = m_incidenceMap.values(incidence->instanceIdentifier());
+        const QList<KCalendarCore::Incidence::Ptr> existingIncidences = m_incidenceMap.values(incidence->instanceIdentifier());
 
         if (existingIncidences.count() == 1) {
             continue;
@@ -464,10 +467,11 @@ void CalendarJanitor::sanityCheck8()
     int numEmptyRID = 0;
     QHash<KCalendarCore::Incidence::IncidenceType, int> m_counts;
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         if (!incidence->attachments().isEmpty()) {
-            foreach (const KCalendarCore::Attachment &attachment, incidence->attachments()) {
+            const auto attachments = incidence->attachments();
+            for (const KCalendarCore::Attachment &attachment : attachments) {
                 if (!attachment.isUri()) {
                     numAttachments++;
                     totalAttachmentSize += attachment.size();
@@ -509,13 +513,13 @@ void CalendarJanitor::sanityCheck8()
         m_returnCode = -2;
     }
 
-    endTest(/**print=*/ false);
+    endTest(/**print=*/false);
 }
 
 void CalendarJanitor::sanityCheck9()
 {
     beginTest(i18n("Checking for RECURRING-ID incidences with nonexistent master incidence..."));
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         if (incidence->recurs() && incidence->hasRecurrenceId() && !m_calendar->incidence(incidence->uid())) {
             printFound(item);
@@ -555,15 +559,14 @@ void CalendarJanitor::sanityCheck9()
         }
     }
 
-    endTest(true, i18n("In fix mode the RECURRING-ID property will be unset and UID changed."),
-            i18n("Recurrence cleared."));
+    endTest(true, i18n("In fix mode the RECURRING-ID property will be unset and UID changed."), i18n("Recurrence cleared."));
 }
 
 void CalendarJanitor::stripOldAlarms()
 {
     beginTest(i18n("Deleting alarms older than 365 days..."));
 
-    foreach (const Akonadi::Item &item, m_itemsToProcess) {
+    for (const Akonadi::Item &item : qAsConst(m_itemsToProcess)) {
         KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
         if (!incidence->alarms().isEmpty() && incidenceIsOld(incidence)) {
             incidence->clearAlarms();
